@@ -1,11 +1,12 @@
 import fractions
+import sys
 
 import pytest
 from packaging.specifiers import SpecifierSet
-from yaml.representer import RepresenterError
 
+import asdf
 from asdf import AsdfFile, config_context
-from asdf.exceptions import AsdfWarning, ValidationError
+from asdf.exceptions import AsdfManifestURIMismatchWarning, AsdfSerializationError, AsdfWarning, ValidationError
 from asdf.extension import (
     Compressor,
     Converter,
@@ -18,6 +19,7 @@ from asdf.extension import (
     Validator,
     get_cached_extension_manager,
 )
+from asdf.extension._manager import _resolve_type
 from asdf.testing.helpers import roundtrip_object
 
 
@@ -575,7 +577,7 @@ def test_converter_subclass_with_no_supported_tags():
     tree = {"obj": Foo()}
     with config_context() as cfg:
         cfg.add_extension(FooExtension())
-        with pytest.raises(RepresenterError, match=r"cannot represent an object"):
+        with pytest.raises(AsdfSerializationError, match=r"is not serializable by asdf"):
             roundtrip_object(tree)
 
 
@@ -897,7 +899,7 @@ def test_warning_or_error_for_default_select_tag(is_subclass, indirect):
             config.add_extension(extension)
 
 
-def test_reference_cycle():
+def test_reference_cycle(tmp_path, with_lazy_tree):
     class FractionWithInverse(fractions.Fraction):
         def __init__(self, *args, **kwargs):
             self._inverse = None
@@ -938,6 +940,112 @@ def test_reference_cycle():
         f2 = FractionWithInverse(5, 3)
         f1.inverse = f2
         f2.inverse = f1
+        fn = tmp_path / "test.asdf"
+        asdf.AsdfFile({"obj": f1}).write_to(fn)
+        with asdf.open(fn) as af:
+            read_f1 = af["obj"]
+            assert read_f1.inverse.inverse is read_f1
 
-        read_f1 = roundtrip_object(f1)
-        assert read_f1.inverse.inverse is read_f1
+
+def test_manifest_uri_id_mismatch_warning(tmp_path):
+    with config_context() as config:
+        # make an extension with a manifest (where id doesn't match the registered uri)
+        full_manifest = """%YAML 1.1
+---
+id: asdf://somewhere.org/manifests/foo
+extension_uri: asdf://somewhere.org/extensions/foo
+tags:
+  - asdf://somewhere.org/tags/bar
+...
+"""
+        config.add_resource_mapping({"asdf://somewhere.org/extensions/foo": full_manifest})
+
+        class Foo:
+            pass
+
+        class FooConverter:
+            tags = ["asdf://somewhere.org/tags/bar"]
+            types = [Foo]
+
+            def to_yaml_tree(self, *args):
+                return {}
+
+            def from_yaml_tree(self, *args):
+                return Foo()
+
+        extension = ManifestExtension.from_uri(
+            "asdf://somewhere.org/extensions/foo",
+            converters=[FooConverter()],
+        )
+
+        # use the extension to write out a file
+        config.add_extension(extension)
+
+        af = AsdfFile()
+        af["foo"] = Foo()
+        fn = tmp_path / "foo.asdf"
+        with pytest.warns(AsdfManifestURIMismatchWarning):
+            af.write_to(fn)
+
+
+def test_resolve_type_not_imported():
+    path = "mailbox.Mailbox"
+
+    if "mailbox" in sys.modules:
+        del sys.modules["mailbox"]
+
+    assert _resolve_type(path) is None
+
+    import mailbox
+
+    assert _resolve_type(path) is mailbox.Mailbox
+
+
+@pytest.mark.parametrize(
+    "path, obj", (("sys", sys), ("asdf.AsdfFile", AsdfFile), ("asdf.Missing", None), ("not_a_module", None))
+)
+def test_resolve_type(path, obj):
+    assert _resolve_type(path) is obj
+
+
+def test_extension_converter_by_class_path():
+    class MailboxConverter:
+        tags = ["asdf://example.com/tags/mailbox-1.0.0"]
+        types = ["mailbox.Mailbox"]
+
+        def to_yaml_tree(self, obj, tag, ctx):
+            return {}
+
+        def from_yaml_tree(self, node, tag, ctx):
+            return None
+
+    class MailboxExtension:
+        tags = MailboxConverter.tags
+        converters = [MailboxConverter()]
+        extension_uri = "asdf://example.com/extensions/mailbox-1.0.0"
+
+    # grab the type so we can use it for extension_manager.get_converter_for_type
+    import mailbox
+
+    typ = mailbox.Mailbox
+    del sys.modules["mailbox"], mailbox
+
+    with config_context() as cfg:
+        cfg.add_extension(MailboxExtension())
+        extension_manager = AsdfFile().extension_manager
+
+        # make sure that registering the extension did not load the module
+        assert "mailbox" not in sys.modules
+
+        # as the module hasn't been loaded, the converter shouldn't be found
+        with pytest.raises(KeyError, match="No support available for Python type 'mailbox.Mailbox'"):
+            extension_manager.get_converter_for_type(typ)
+
+        # make sure inspecting the type didn't import the module
+        assert "mailbox" not in sys.modules
+
+        # finally, import the module and check that the converter can now be found
+        import mailbox
+
+        converter = extension_manager.get_converter_for_type(mailbox.Mailbox)
+        assert isinstance(converter.delegate, MailboxConverter)
