@@ -10,34 +10,18 @@ from operator import methodcaller
 
 import numpy as np
 import yaml
-from jsonschema import validators as mvalidators
-from jsonschema.exceptions import RefResolutionError, ValidationError
 
-from . import constants, extension, generic_io, reference, tagged, treeutil, util, versioning, yamlutil
+from asdf._jsonschema import validators as mvalidators
+from asdf._jsonschema.exceptions import RefResolutionError, ValidationError
+
+from . import constants, generic_io, reference, tagged, treeutil, util, versioning, yamlutil
 from .config import get_config
 from .exceptions import AsdfDeprecationWarning, AsdfWarning
-from .extension import _legacy
-from .util import patched_urllib_parse
+from .util import _patched_urllib_parse
 
 YAML_SCHEMA_METASCHEMA_ID = "http://stsci.edu/schemas/yaml-schema/draft-01"
 
-
-__all__ = ["validate", "fill_defaults", "remove_defaults", "check_schema"]
-
-
-def default_ext_resolver(uri):
-    """
-    Resolver that uses tag/url mappings from all installed extensions
-    """
-    # Deprecating this because it doesn't play nicely with the caching on
-    # load_schema(...).
-    warnings.warn(
-        "The 'default_ext_resolver(...)' function is deprecated. Use "
-        "'asdf.extension.get_default_resolver()(...)' instead.",
-        AsdfDeprecationWarning,
-    )
-    return extension.get_default_resolver()(uri)
-
+__all__ = ["validate", "fill_defaults", "remove_defaults", "check_schema", "load_schema"]
 
 PYTHON_TYPE_TO_YAML_TAG = {
     None: "null",
@@ -65,6 +49,16 @@ def _type_to_tag(type_):
     return None
 
 
+def _tag_to_uri(input_str):
+    if not input_str.startswith(constants.STSCI_SCHEMA_TAG_BASE):
+        return input_str
+    warnings.warn(
+        "Resolving by tag is deprecated. Use uris instead of tags",
+        AsdfDeprecationWarning,
+    )
+    return f"http://stsci.edu/schemas/asdf{input_str[len(constants.STSCI_SCHEMA_TAG_BASE):]}"
+
+
 def validate_tag(validator, tag_pattern, instance, schema):
     """
     Implements the tag validation directive, which checks the
@@ -82,7 +76,7 @@ def validate_tag(validator, tag_pattern, instance, schema):
         yield ValidationError(f"mismatched tags, wanted '{tag_pattern}', got '{instance_tag}'")
 
 
-def validate_propertyOrder(validator, order, instance, schema):  # noqa: N802
+def validate_propertyOrder(validator, order, instance, schema):
     """
     Stores a value on the `tagged.TaggedDict` instance so that
     properties can be written out in the preferred order.  In that
@@ -100,7 +94,7 @@ def validate_propertyOrder(validator, order, instance, schema):  # noqa: N802
     instance.property_order = order
 
 
-def validate_flowStyle(validator, flow_style, instance, schema):  # noqa: N802
+def validate_flowStyle(validator, flow_style, instance, schema):
     """
     Sets a flag on the `tagged.TaggedList` or `tagged.TaggedDict`
     object so that the YAML generator knows which style to use to
@@ -209,6 +203,8 @@ class _ValidationContext:
     when exiting the outermost context.
     """
 
+    __slots__ = ["_depth", "_seen"]
+
     def __init__(self):
         self._depth = 0
         self._seen = set()
@@ -243,7 +239,7 @@ class _ValidationContext:
 
 @lru_cache
 def _create_validator(validators=YAML_VALIDATORS, visit_repeat_nodes=False):
-    meta_schema = _load_schema_cached(YAML_SCHEMA_METASCHEMA_ID, _legacy.get_default_resolver(), False, False)
+    meta_schema = _load_schema_cached(YAML_SCHEMA_METASCHEMA_ID, _tag_to_uri, False)
 
     type_checker = mvalidators.Draft4Validator.TYPE_CHECKER.redefine_many(
         {
@@ -253,7 +249,7 @@ def _create_validator(validators=YAML_VALIDATORS, visit_repeat_nodes=False):
         },
     )
     id_of = mvalidators.Draft4Validator.ID_OF
-    ASDFvalidator = mvalidators.create(  # noqa: N806
+    ASDFvalidator = mvalidators.create(
         meta_schema=meta_schema,
         validators=validators,
         type_checker=type_checker,
@@ -295,14 +291,9 @@ def _create_validator(validators=YAML_VALIDATORS, visit_repeat_nodes=False):
 
                 if not self.schema:
                     tag = getattr(instance, "_tag", None)
-                    if tag is not None:
-                        if self.serialization_context.extension_manager.handles_tag_definition(tag):
-                            tag_def = self.serialization_context.extension_manager.get_tag_definition(tag)
-                            schema_uris = tag_def.schema_uris
-                        else:
-                            schema_uris = [self.ctx._tag_mapping(tag)]
-                            if schema_uris[0] == tag:
-                                schema_uris = []
+                    if tag is not None and self.serialization_context.extension_manager.handles_tag_definition(tag):
+                        tag_def = self.serialization_context.extension_manager.get_tag_definition(tag)
+                        schema_uris = tag_def.schema_uris
 
                         # Must validate against all schema_uris
                         for schema_uri in schema_uris:
@@ -348,6 +339,9 @@ def _load_schema(url):
 
 
 def _make_schema_loader(resolver):
+    if resolver is None:
+        resolver = _tag_to_uri
+
     def load_schema(url):
         # Check if this is a URI provided by the new
         # Mapping API:
@@ -375,7 +369,7 @@ def _make_schema_loader(resolver):
     return load_schema
 
 
-def _make_resolver(url_mapping):
+def _make_jsonschema_refresolver(url_mapping):
     handlers = {}
     schema_loader = _make_schema_loader(url_mapping)
 
@@ -387,7 +381,7 @@ def _make_resolver(url_mapping):
 
     # Supplying our own implementation of urljoin_cache
     # allows asdf:// URIs to be resolved correctly.
-    urljoin_cache = lru_cache(1024)(patched_urllib_parse.urljoin)
+    urljoin_cache = lru_cache(1024)(_patched_urllib_parse.urljoin)
 
     # We set cache_remote=False here because we do the caching of
     # remote schemas here in `load_schema`, so we don't need
@@ -402,16 +396,7 @@ def _make_resolver(url_mapping):
     )
 
 
-@lru_cache
-def load_custom_schema(url):
-    warnings.warn(
-        "The 'load_custom_schema(...)' function is deprecated. Use 'load_schema' instead.",
-        AsdfDeprecationWarning,
-    )
-    return load_schema(url, resolve_references=True)
-
-
-def load_schema(url, resolver=None, resolve_references=False, resolve_local_refs=False):
+def load_schema(url, resolver=None, resolve_references=False):
     """
     Load a schema from the given URL.
 
@@ -427,27 +412,16 @@ def load_schema(url, resolver=None, resolve_references=False, resolve_local_refs
         mirror on the local filesystem that you wish to use.
 
     resolve_references : bool, optional
-        If `True`, resolve all `$ref` references.
+        If ``True``, resolve all ``$ref`` references.
 
-    resolve_local_refs : bool, optional
-        If `True`, resolve all `$ref` references that refer to other objects
-        within the same schema. This will automatically be handled when passing
-        `resolve_references=True`, but it may be desirable in some cases to
-        control local reference resolution separately.
-        This parameter is deprecated.
     """
-    if resolve_local_refs is True:
-        warnings.warn("The 'resolve_local_refs' parameter is deprecated.", AsdfDeprecationWarning)
-
     if resolver is None:
-        # We can't just set this as the default in load_schema's definition
-        # because invoking get_default_resolver at import time leads to a circular import.
-        resolver = _legacy.get_default_resolver()
+        resolver = _tag_to_uri
 
     # We want to cache the work that went into constructing the schema, but returning
     # the same object is treacherous, because users who mutate the result will not
     # expect that they're changing the schema everywhere.
-    return copy.deepcopy(_load_schema_cached(url, resolver, resolve_references, resolve_local_refs))
+    return copy.deepcopy(_load_schema_cached(url, resolver, resolve_references))
 
 
 def _safe_resolve(resolver, json_id, uri):
@@ -489,11 +463,13 @@ def _safe_resolve(resolver, json_id, uri):
 
 
 @lru_cache
-def _load_schema_cached(url, resolver, resolve_references, resolve_local_refs):
+def _load_schema_cached(url, resolver, resolve_references):
+    if resolver is None:
+        resolver = _tag_to_uri
     loader = _make_schema_loader(resolver)
     schema, url = loader(url)
 
-    if resolve_references or resolve_local_refs:
+    if resolve_references:
 
         def resolve_refs(node, json_id):
             if json_id is None:
@@ -505,12 +481,8 @@ def _load_schema_cached(url, resolver, resolve_references, resolve_local_refs):
                 if suburl_base == url or suburl_base == schema.get("id"):
                     # This is a local ref, which we'll resolve in both cases.
                     subschema = schema
-                elif resolve_references:
-                    # Only resolve non-local refs when the flag is set.
-                    subschema = load_schema(suburl_base, resolver, True)
                 else:
-                    # Otherwise return the $ref unmodified.
-                    return node
+                    subschema = load_schema(suburl_base, resolver, True)
 
                 return reference.resolve_fragment(subschema, suburl_fragment)
 
@@ -518,7 +490,7 @@ def _load_schema_cached(url, resolver, resolve_references, resolve_local_refs):
 
         schema = treeutil.walk_and_modify(schema, resolve_refs)
 
-    return schema  # noqa: RET504
+    return schema
 
 
 def get_validator(
@@ -535,7 +507,7 @@ def get_validator(
     Get a JSON schema validator object for the given schema.
 
     The additional *args and **kwargs are passed along to
-    `~jsonschema.Validator.validate`.
+    `~jsonschema.protocols.Validator.validate`.
 
     Parameters
     ----------
@@ -550,8 +522,9 @@ def get_validator(
         A dictionary mapping properties to validators to use (instead
         of the built-in ones and ones provided by extension types).
 
-    url_mapping : resolver.Resolver, optional
-        A resolver to convert remote URLs into local ones.
+    url_mapping : callable, optional
+        A callable that takes one string argument and returns a string
+        to convert remote URLs into local ones.
 
     _visit_repeat_nodes : bool, optional
         Force the validator to visit nodes that it has already
@@ -565,7 +538,7 @@ def get_validator(
     validator : jsonschema.Validator
     """
     if ctx is None:
-        from .asdf import AsdfFile
+        from ._asdf import AsdfFile
 
         ctx = AsdfFile()
 
@@ -574,10 +547,9 @@ def get_validator(
 
     if validators is None:
         validators = util.HashableDict(YAML_VALIDATORS.copy())
-        validators.update(ctx._extension_list.validators)
         validators.update(ctx._extension_manager.validator_manager.get_jsonschema_validators())
 
-    kwargs["resolver"] = _make_resolver(url_mapping)
+    kwargs["resolver"] = _make_jsonschema_refresolver(url_mapping)
 
     # We don't just call validators.validate() directly here, because
     # that validates the schema itself, wasting a lot of time (at the
@@ -646,7 +618,7 @@ def validate(instance, ctx=None, schema=None, validators=None, reading=False, *a
     tag on the instance.
 
     The additional ``*args`` and ``**kwargs`` are passed along to
-    `~jsonschema.Validator.validate`.
+    `~jsonschema.protocols.Validator.validate`.
 
     Parameters
     ----------
@@ -669,11 +641,11 @@ def validate(instance, ctx=None, schema=None, validators=None, reading=False, *a
         reading vs writing files.
     """
     if ctx is None:
-        from .asdf import AsdfFile
+        from ._asdf import AsdfFile
 
         ctx = AsdfFile()
 
-    validator = get_validator({} if schema is None else schema, ctx, validators, ctx._resolver, *args, **kwargs)
+    validator = get_validator({} if schema is None else schema, ctx, validators, None, *args, **kwargs)
     validator.validate(instance)
 
     additional_validators = [_validate_large_literals]
@@ -763,9 +735,9 @@ def check_schema(schema, validate_default=True):
         applicable_validators = methodcaller("items")
 
     meta_schema_id = schema.get("$schema", YAML_SCHEMA_METASCHEMA_ID)
-    meta_schema = _load_schema_cached(meta_schema_id, _legacy.get_default_resolver(), False, False)
+    meta_schema = _load_schema_cached(meta_schema_id, _tag_to_uri, False)
 
-    resolver = _make_resolver(_legacy.get_default_resolver())
+    resolver = _make_jsonschema_refresolver(_tag_to_uri)
 
     cls = mvalidators.create(
         meta_schema=meta_schema,
